<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       none
 * @since      1.0.0
 *
 * @package    Twitch_Player
 * * @subpackage Twitch_Player/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Twitch_Player
 * * @subpackage Twitch_Player/admin
 * @author     StreamWeasels <admin@streamweasels.com>
 */
class Twitch_Player_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Twitch_Player_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Twitch_Player_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		if (isset($_GET['page']) && $_GET['page'] == 'twitch-tv-player') {
			wp_enqueue_style( 'twitch-tv-easy-embed-admin-css', plugin_dir_url( __FILE__ ) . 'css/twitch-player-admin.css', array(), $this->version, 'all' );
            wp_enqueue_style( 'twitch-tv-easy-embed-plugin-css', plugins_url( 'public/css/twitch-player-public.css', dirname(__FILE__) ), array(), '', 'all' );
            wp_enqueue_style( 'wp-color-picker' );
            wp_enqueue_script( 'twitch-ttv-player-js', plugins_url( '/public/js/twitch-player-public.js', dirname( __FILE__ ) ), array('jquery'), $this->version, false );            
            $twitchPlayerVars = array(
                'id'            => 0,
                'language'      => sanitize_text_field(get_option('ttv_ezembed_options_player')['twitch_settings_language']),  
                'twitchGames'   => sanitize_text_field(get_option('ttv_ezembed_options_player')['twitch_settings_game']),
                'showOffline'   => sanitize_text_field(get_option('ttv_ezembed_options_player')['twitch_player_settings_channel_offline']),                
				'twitchChannelNames'   => str_replace(' ', '', sanitize_text_field(get_option('ttv_ezembed_options_player')['twitch_settings_channel'])),
                'twitchChannelIds'   => str_replace(' ', '', sanitize_text_field(get_option('ttv_ezembed_options_player')['twitch_settings_channel_id'])),				
				'twitchTeamNames'    => strtolower(sanitize_text_field(get_option('ttv_ezembed_options_player')['twitch_settings_team_names'])),
                'twitchTeamIds'    => strtolower(sanitize_text_field(get_option('ttv_ezembed_options_player')['twitch_settings_team_id'])),				
                'limit'         => sanitize_text_field(get_option('ttv_ezembed_options_player')['twitch_settings_limit']),                
                'theme'         => sanitize_text_field(get_option('ttv_ezembed_appearance_options_player')['twitch_appearance_colour_theme'])                
            );            
            wp_localize_script( 'twitch-ttv-player-js', 'twitch_player_vars', $twitchPlayerVars);
		}

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Twitch_Player_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Twitch_Player_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		if (isset($_GET['page']) && $_GET['page'] == 'twitch-tv-player') {
            wp_enqueue_script( 'twitch-API', 'https://embed.twitch.tv/embed/v1.js', array( 'jquery' ), '', false );
			wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/twitch-player-admin.js', array( 'jquery' ), $this->version, false );
			wp_enqueue_script( 'twitch-colourpicker', plugin_dir_url( __FILE__ ) . 'js/colour-picker.js', array( 'wp-color-picker' ), $this->version, false );
		}

	}
    
	public function create_admin_page() {
		add_options_page( 'Twitch TV Player', 'Easy Embed for Twitch TV (PLAYER)', 'manage_options', 'twitch-tv-player', 'ttv_ezembed_options_player' );

		function ttv_ezembed_options_player() {
		    $twitchOptions = get_option('ttv_ezembed_options_player');
		    $active_tab = isset( $_GET[ 'tab' ] ) ? $_GET[ 'tab' ] : 'main_options';

			echo '<div class="'.$active_tab.'">
		    <h2>Easy Embed for Twitch TV (Player)</h2>
		    <p>Easily add a customizable Twitch.tv embedded player anywhere on your site. Fill in the options below to customize your player.</p>';
            echo '<h2 style="text-align:center;">Layout Options</h2>';                
            echo '<p style="text-align:center;">Why not try one of our other Easy Embed Twitch TV plugins?</p>';
            echo '<p style="text-align:center;">Or if you\'re a streamer, why not try our FREE WordPress theme, integrated with Twitch straight out the box - <a href="https://www.streamweasels.com" target="_blank">Broadcast</a></p>';
            echo '<div class="twitch-plugins-upsell">';
            echo '<div class="twitch-plugins-upsell-item"><a target="_blank" href="https://en-gb.wordpress.org/plugins/ttv-easy-embed/"><img src="'.plugin_dir_url( __FILE__ ).'../admin/img/twitch-rail.png"></a><span>A customizable Twitch Rail - which shows three streams at a time and lets the users swipe streams left and right.</span><a href="https://en-gb.wordpress.org/plugins/ttv-easy-embed/" target="_blank">Twitch Rail</a></div>';
            echo '<div class="twitch-plugins-upsell-item"><a target="_blank" href="https://en-gb.wordpress.org/plugins/ttv-easy-embed-wall/"><img src="'.plugin_dir_url( __FILE__ ).'../admin/img/twitch-wall.png"></a><span>A customizable Twitch Wall - which shows many streams, which when clicked - activate the \'featured stream\' at the top. Includes chat.</span><a href="https://en-gb.wordpress.org/plugins/ttv-easy-embed-wall/" target="_blank">Twitch Wall</a></div>';     
			echo '<div class="twitch-plugins-upsell-item"><a target="_blank" href="https://en-gb.wordpress.org/plugins/ttv-easy-embed-player/"><img src="'.plugin_dir_url( __FILE__ ).'../admin/img/twitch-player.png"></a><span>A customizable Twitch Player - which shows many streams, when clicked - activate the \'featured stream\' in the middle. Includes offline.</span><a href="https://en-gb.wordpress.org/plugins/ttv-easy-embed-player/" target="_blank">Twitch Player</a></div>';            
			echo '<div class="twitch-plugins-upsell-item"><a target="_blank" href="https://www.streamweasels.com/store/themes/broadcast-pro/?ref=plugins"><img src="'.plugin_dir_url( __FILE__ ).'../admin/img/broadcast.jpg"></a><span>A <strong>WordPress Theme</strong> built specifically for streamers. Twitch, Mixer and YouTube integration built-in.</span><a href="https://www.streamweasels.com/store/themes/broadcast-pro/?ref=plugins" target="_blank">Broadcast PRO Theme</a></div>';            
			echo '<div class="twitch-plugins-upsell-item"><a target="_blank" href="https://www.streamweasels.com/store/themes/ultima-gaming/?ref=plugins"><img src="'.plugin_dir_url( __FILE__ ).'../admin/img/ultima.jpg"></a><span><strong>Just Launched</strong>: Our new <strong>WordPress Theme</strong> built for streamers, gamers, esports, clans, teams and gaming communities.</span><a href="https://www.streamweasels.com/store/themes/ultima-gaming/?ref=plugins" target="_blank">Ultima Gaming Theme</a></div>'; 
            echo '</div>';            
		    echo '<h2 class="nav-tab-wrapper">
			    <a href="?page=twitch-tv-player&tab=main_options" class="nav-tab '.  ($active_tab == 'main_options' ? 'nav-tab-active' : '') .'">Main Options</a>
			    <a href="?page=twitch-tv-player&tab=appearance_options" class="nav-tab '.  ($active_tab == 'appearance_options' ? 'nav-tab-active' : '') .'">Appearance Options</a>                
				</h2>';
            echo '<h2 style="text-align:center;">Twitch Player Preview</h2>';
		    echo '<p style="text-align:center;">Shortcode to output the Twitch TV Player: [getTwitchPlayer]</p></div>';
            echo '<p style="text-align:center;">Upgrade to <a href="https://www.streamweasels.com/store/plugins/twitch-tv-player-pro/" target="_blank">Twitch TV Player PRO</a> to get advanced shortcode usage, which allows for <strong>multiple players</strong>.</p>';
		    include (plugin_dir_path( __FILE__ ) . '/../public/partials/output.php');
		    echo '<form class="twitch-form" action="options.php" method="post">';
		    if( $active_tab == 'main_options' ) {
		    settings_fields('ttv_ezembed_options_player');
		    do_settings_sections('twitch_player');
		    } elseif ( $active_tab == 'appearance_options' ) {
		    settings_fields('ttv_ezembed_appearance_options_player');
		    do_settings_sections('twitch_player_2');
		    }
		    echo '<input name="Submit" type="submit" value="Save Changes" />
		    </form>';
		}
	}

	function ttv_ezembed_admin_init() {

	include ('partials/fields-output.php');
	include ('partials/sanitize.php');

	register_setting( 'ttv_ezembed_options_player', 'ttv_ezembed_options_player', 'ttv_ezembed_options_player_validate');
	register_setting( 'ttv_ezembed_appearance_options_player', 'ttv_ezembed_appearance_options_player', 'ttv_ezembed_options_player_validate'); 
	add_settings_section('twitch_main_player', 'Main Settings', 'twitch_player_section_text', 'twitch_player');
	add_settings_section('twitch_appearance_player', 'Appearance Settings', 'twitch_player_section_appearance_text', 'twitch_player_2');
	add_settings_field('twitch_settings_game', 'Game', 'twitch_player_settings_game', 'twitch_player', 'twitch_main_player');
	add_settings_field('twitch_settings_language', 'Language', 'twitch_player_settings_language', 'twitch_player', 'twitch_main_player');    
	add_settings_field('twitch_settings_channel', 'Channel', 'twitch_player_settings_channel', 'twitch_player', 'twitch_main_player');
	add_settings_field('twitch_settings_team', 'Team', 'twitch_player_settings_team', 'twitch_player', 'twitch_main_player');
	add_settings_field('twitch_settings_limit', 'Limit', 'twitch_player_settings_limit', 'twitch_player', 'twitch_main_player');
	add_settings_field('twitch_appearance_colour_theme', 'Colour Theme', 'twitch_player_appearance_colour_theme', 'twitch_player_2', 'twitch_appearance_player');
	add_settings_field('twitch_player_settings_channel_offline', 'Show Offline Channels?', 'twitch_player_settings_channel_offline', 'twitch_player', 'twitch_main_player'); 
	add_settings_field('twitch_player_settings_show_default', 'Show Featured Stream by default?', 'twitch_player_settings_show_default', 'twitch_player', 'twitch_main_player');     
	add_settings_field('twitch_player_settings_show_chat', 'Show Chat?', 'twitch_player_settings_show_chat', 'twitch_player', 'twitch_main_player');        


	function twitch_player_section_text() {
	echo '<p>Fill in the below fields to hook your Twitch Player upto twitch.tv. Fill in either the game field or the channels field to start pulling streams from twitch!</p>';
	}
	function twitch_player_section_appearance_text() {
	echo '<p>Fill in the below fields to fully configure the twitch.TV Player.</p>';
	}        
}

}
