<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       none
 * @since      1.0.0
 *
 * @package    Twitch_Player
 * * @subpackage Twitch_Player/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Twitch_Player
 * * @subpackage Twitch_Player/public
 * @author     StreamWeasels <admin@streamweasels.com>
 */
class Twitch_Player_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Twitch_Player_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Twitch_Player_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/twitch-player-public.css', array(), '', 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Twitch_Player_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Twitch_Player_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( 'twitch-API', 'https://embed.twitch.tv/embed/v1.js', array( 'jquery' ), '', false );
        wp_enqueue_script( 'twitch-ttv-player-js', plugins_url( '/public/js/twitch-player-public.js', dirname( __FILE__ ) ), array('jquery'), $this->version, false );            
        $twitchPlayerVars = array(
            'id'            => 0,
            'language'      => sanitize_text_field(get_option('ttv_ezembed_options_player')['twitch_settings_language']),  
            'twitchGames'   => sanitize_text_field(get_option('ttv_ezembed_options_player')['twitch_settings_game']),
			'showOffline'   => sanitize_text_field(get_option('ttv_ezembed_options_player')['twitch_player_settings_channel_offline']),                
			'twitchChannelNames'   => str_replace(' ', '', sanitize_text_field(get_option('ttv_ezembed_options_player')['twitch_settings_channel'])),
			'twitchChannelIds'   => str_replace(' ', '', sanitize_text_field(get_option('ttv_ezembed_options_player')['twitch_settings_channel_id'])),				
			'twitchTeamNames'    => strtolower(sanitize_text_field(get_option('ttv_ezembed_options_player')['twitch_settings_team_names'])),
			'twitchTeamIds'    => strtolower(sanitize_text_field(get_option('ttv_ezembed_options_player')['twitch_settings_team_id'])),
            'limit'         => sanitize_text_field(get_option('ttv_ezembed_options_player')['twitch_settings_limit']),                
            'theme'         => sanitize_text_field(get_option('ttv_ezembed_appearance_options_player')['twitch_appearance_colour_theme'])                             
        );            
        wp_localize_script( 'twitch-ttv-player-js', 'twitch_player_vars', $twitchPlayerVars);        
	}
    
    public function getTwitchOutput($args){
        include ('partials/output.php');
    }
    
	public function getTwitchPlayerShortcode() {
		add_shortcode('getTwitchPlayer',  array( $this, 'getTwitchPlayer_content'));
	}
    
	public function getTwitchPlayer_content($args, $content=''){
        ob_start();
        $this->getTwitchOutput($args);
        return ob_get_clean();
	}   
    
}

